Configuration file — Scrapple 0.2.3 documentation

### Navigation

- index
- next |
- previous |
- Scrapple 0.2.3 documentation »

# Configuration file

#### Previous topic

Scrapple commands

#### Next topic

Authors

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- Scrapple 0.2.3 documentation »

© Copyright 2014, Alex Mathew, Harish Balakrishnan. Created using Sphinx 1.2.3.